Documentation
¶
Index ¶
Constants ¶
const ( ImportantLevel = int(zapcore.ErrorLevel) InfoLevel = int(zapcore.InfoLevel) DebugLevel = int(zapcore.DebugLevel) PerformanceTestLevel = -128 )
Variables ¶
This section is empty.
Functions ¶
func CreateDebugLogger ¶
func CreateLogger ¶
CreateLogger creates a new logger instance isDebug: if enabled, the logger prints debug logs, otherwise it prints info level and above
func GetObservedLogs ¶
func GetObservedLogs() *observer.ObservedLogs
GetObservedLogs returns ObservedLogs object, can be used in unit tests to see if something got logged
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.